==> TSMasterAPI-2025.8.6.1576.tar.gz: TSMasterAPI-2025.8.6.1576/TSMasterAPI/TSCallback.py <==
from .TSStruct import * 
TCProcedure = CFUNCTYPE(None,)
# Arg[0] AData
TCANQueueEvent_API = WINFUNCTYPE(None,PLIBCAN)
# Arg[0] AObj
# Arg[1] AData
TGPSQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBGPSData)
# Arg[0] AObj
# Arg[1] AData
TCANQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBCAN)
# Arg[0] AObj
# Arg[1] AData
TCANFDQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBCANFD)
# Arg[0] AObj
# Arg[1] AData
TFlexRayQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBFlexRay)
# Arg[0] AObj
# Arg[1] AData
TEthernetQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBEthernetHeader)
# Arg[0] AObj
# Arg[1] AData
TLINQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBLIN)
# Arg[0] AStr
# Arg[1] ALevel
TLIBTSMasterLogger = WINFUNCTYPE(None,pchar,s32)
# Arg[0] APointer
# Arg[1] ASize
TOnIoIPData = WINFUNCTYPE(None,ps32,s32)
# Arg[0] APointer
# Arg[1] ASize
TOnRpcData = WINFUNCTYPE(None,ps32,size_t)
# Arg[0] ACAN
# Arg[1] ADataId
# Arg[2] AValue
TOnAutoSARE2ECanEvt = WINFUNCTYPE(None,PLIBCANFD,u32,pu64)
# Arg[0] AChnIdx
# Arg[1] APDUName
# Arg[2] ATimestamp
# Arg[3] AIsTx
# Arg[4] AID
# Arg[5] ADataLength
# Arg[6] AData
TOnAutoSARPDUQueueEvent = WINFUNCTYPE(None,s32,pchar,u64,u8,u32,u32,pu8)
# Arg[0] AChnIdx
# Arg[1] APDUName
# Arg[2] AID
# Arg[3] ASrcDataLength
# Arg[4] ASrcData
# Arg[5] ADestDataLength
# Arg[6] ADestData
TOnAutoSARPDUPreTxEvent = WINFUNCTYPE(s32,s32,pchar,u32,u32,pu8,pu32,pu8)
# Arg[0] AVidPid
# Arg[1] ASerial
TOnUSBPlugEvent = WINFUNCTYPE(None,pchar,pchar)
# Arg[0] APointer
# Arg[1] ASize
TOnIoIPData_API = WINFUNCTYPE(None,ps32,s32)
# Arg[0] AIPAddress
# Arg[1] APort
TOnIoIPConnection = WINFUNCTYPE(None,pchar,s32)
# Arg[0] AIPAddress
# Arg[1] APort
TOnIoIPConnection_API = WINFUNCTYPE(None,pchar,s32)
# Arg[0] AObj
# Arg[1] AName
# Arg[2] AGroup
# Arg[3] ADesc
# Arg[4] AExample
# Arg[5] AParaCount
TLIBWriteAPIDocumentFunc = WINFUNCTYPE(None,ps32,pchar,pchar,pchar,pchar,s32)
# Arg[0] AObj
# Arg[1] AIdx
# Arg[2] AAPIName
# Arg[3] AParaName
# Arg[4] AIsConst
# Arg[5] AParaType
# Arg[6] ADesc
TLIBWriteAPIParaFunc = WINFUNCTYPE(None,ps32,s32,pchar,pchar,cbool,pchar,pchar)
# Arg[0] AObj
# Arg[1] AWriteDoc
# Arg[2] AWritePara
TLIBWriteAPIDocument = WINFUNCTYPE(None,ps32,TLIBWriteAPIDocumentFunc,TLIBWriteAPIParaFunc)
TLIBCheckResult = WINFUNCTYPE(cbool,)
# Arg[0] ACompleteName
TLIBOnSysVarChange = WINFUNCTYPE(None,pchar)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AClientSocket
# Arg[3] AResult
TSSocketListenEvent = WINFUNCTYPE(None,ps32,s32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
TSSocketNotifyEvent = WINFUNCTYPE(None,ps32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AAddr
# Arg[4] APort
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEvent = WINFUNCTYPE(None,ps32,s32,s32,u32,u32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ARemoteEndPoint
# Arg[4] AData
# Arg[5] ASize
TSSocketReceiveEventV2 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ADstEndPoint
# Arg[4] ASrcEndPoint
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEventV3 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AData
# Arg[4] ASize
TSSocketTransmitEvent = WINFUNCTYPE(None,ps32,s32,s32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AClientSocket
# Arg[3] AResult
TSSocketListenEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
TSSocketNotifyEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AAddr
# Arg[4] APort
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,u32,u32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ARemoteEndPoint
# Arg[4] AData
# Arg[5] ASize
TSSocketReceiveEventV2_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ADstEndPoint
# Arg[4] ASrcEndPoint
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEventV3_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AData
# Arg[4] ASize
TSSocketTransmitEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pu8,s32)
# Arg[0] AIdxChn
# Arg[1] ATimestamp
# Arg[2] APackCmd
# Arg[3] AParameter
# Arg[4] AParameterLength
# Arg[5] AData
# Arg[6] ADataLength
TDatapackageProcessEvent = WINFUNCTYPE(None,u8,s64,u16,pu8,u16,pu8,s32)
# Arg[0] AIdxChn
# Arg[1] ATimestamp
# Arg[2] APackCmd
# Arg[3] AParameter
# Arg[4] AParameterLength
# Arg[5] AData
# Arg[6] ADataLength
TDatapackageProcessEvent_Win32 = WINFUNCTYPE(None,u8,s64,u16,pu8,u16,pu8,s32)
# Arg[0] AObj
# Arg[1] AProgress100
TReadProgressCallback = WINFUNCTYPE(None,ps32,double)
# Arg[0] AObj
# Arg[1] AProgress
TSeekTimeProgressCallback = CFUNCTYPE(s32,ps32,single)
# Arg[0] AObj
# Arg[1] AComment
# Arg[2] AToTerminate
TReadBLFRealtimeCommentCallback = WINFUNCTYPE(None,ps32,Prealtime_comment_t,pbool)
# Arg[0] AObj
# Arg[1] ASysVar
# Arg[2] AToTerminate
TReadBLFSystemVarCallback = WINFUNCTYPE(None,ps32,PLIBSystemVar,pbool)
# Arg[0] AObj
TReadUnsupportedCallback = WINFUNCTYPE(None,ps32)
# Arg[0] pDiagModuleIndex
# Arg[1] AChnIndex
# Arg[2] ASupportFDCAN
# Arg[3] AMaxDLC
# Arg[4] ARequestID
# Arg[5] ARequestIDIsStd
# Arg[6] AResponseID
# Arg[7] AResponseIDIsStd
# Arg[8] AFunctionID
# Arg[9] AFunctionIDIsStd
Ttsdiag_can_create = WINFUNCTYPE(s32,ps32,u32,u8,u8,u32,cbool,u32,cbool,u32,cbool)
# Arg[0] ADiagModuleIndex
# Arg[1] AFDMode
# Arg[2] ASupportBRS
# Arg[3] AMaxDLC
Ttsdiag_set_fdmode = WINFUNCTYPE(s32,s32,cbool,cbool,s32)
# Arg[0] ADiagModuleIndex
Ttsdiag_can_delete = WINFUNCTYPE(s32,s32)
Ttsdiag_can_delete_all = WINFUNCTYPE(None,)
# Arg[0] ADiagModuleIndex
# Arg[1] AReqDataArray
# Arg[2] AReqDataSize
# Arg[3] AResponseDataArray
# Arg[4] AResponseDataSize
Ttstp_can_request_and_get_response = WINFUNCTYPE(s32,s32,pu8,s32,pu8,ps32)
# Arg[0] ADiagModuleIndex
# Arg[1] AReqDataArray
# Arg[2] AReqDataSize
# Arg[3] AResponseDataArray
# Arg[4] AResponseDataSize
Ttstp_can_request_and_get_response_functional = WINFUNCTYPE(s32,s32,pu8,s32,pu8,ps32)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
N_USData_RevData_Recall_Obj = WINFUNCTYPE(None,s32,s32)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
# Arg[2] ABusType
# Arg[3] ANAD
# Arg[4] AIdentifier
# Arg[5] ATimeStamp
# Arg[6] APayLoad
# Arg[7] ASize
# Arg[8] AError
N_USData_TranslateCompleted_Recall_Obj = WINFUNCTYPE(None,s32,s32,u8,s32,s32,u64,pu8,u32,ISO_TP_RESAULT)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
# Arg[2] ATimeStamp
# Arg[3] APayLoad
# Arg[4] ASize
# Arg[5] AError
N_USData_TranslateCompleted_Recall = WINFUNCTYPE(None,s32,s32,u64,pu8,u32,ISO_TP_RESAULT)
# Arg[0] AMsg
# Arg[1] ALevel
TLogDebuggingInfo_t = WINFUNCTYPE(None,pchar,s32)
# Arg[0] sock
# Arg[1] p
# Arg[2] len
tosun_recv_callback = CFUNCTYPE(None,s32,ps32,u16)
# Arg[0] sock
# Arg[1] p
# Arg[2] src
# Arg[3] dest
# Arg[4] ttl
# Arg[5] tos
tosun_tcp_presend_callback = CFUNCTYPE(None,s32,ps32,Pip_addr_t,Pip_addr_t,u8,u8)
# Arg[0] sock
# Arg[1] p
# Arg[2] len
tosun_tcp_ack_callback = CFUNCTYPE(None,s32,ps32,u16)

==> TSMasterAPI-2025.9.13.1637.tar.gz: TSMasterAPI-2025.9.13.1637/TSMasterAPI/TSCallback.py <==
from .TSStruct import * 
TCProcedure = CFUNCTYPE(None,)
# Arg[0] AData
TCANQueueEvent_API = WINFUNCTYPE(None,PLIBCAN)
# Arg[0] AObj
# Arg[1] AData
TGPSQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBGPSData)
# Arg[0] AObj
# Arg[1] AData
TCANQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBCAN)
# Arg[0] AObj
# Arg[1] AData
TCANFDQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBCANFD)
# Arg[0] AObj
# Arg[1] AData
TFlexRayQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBFlexRay)
# Arg[0] AObj
# Arg[1] AData
TEthernetQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBEthernetHeader)
# Arg[0] AObj
# Arg[1] AData
TLINQueueEvent_Win32 = WINFUNCTYPE(None,ps32,PLIBLIN)
# Arg[0] AStr
# Arg[1] ALevel
TLIBTSMasterLogger = WINFUNCTYPE(None,pchar,s32)
# Arg[0] APointer
# Arg[1] ASize
TOnIoIPData = WINFUNCTYPE(None,ps32,s32)
# Arg[0] APointer
# Arg[1] ASize
TOnRpcData = WINFUNCTYPE(None,ps32,size_t)
# Arg[0] ACAN
# Arg[1] ADataId
# Arg[2] AValue
TOnAutoSARE2ECanEvt = WINFUNCTYPE(None,PLIBCANFD,u32,pu64)
# Arg[0] AChnIdx
# Arg[1] APDUName
# Arg[2] ATimestamp
# Arg[3] AIsTx
# Arg[4] AID
# Arg[5] ADataLength
# Arg[6] AData
TOnAutoSARPDUQueueEvent = WINFUNCTYPE(None,s32,pchar,u64,u8,u32,u32,pu8)
# Arg[0] AChnIdx
# Arg[1] APDUName
# Arg[2] AID
# Arg[3] ASrcDataLength
# Arg[4] ASrcData
# Arg[5] ADestDataLength
# Arg[6] ADestData
TOnAutoSARPDUPreTxEvent = WINFUNCTYPE(s32,s32,pchar,u32,u32,pu8,pu32,pu8)
# Arg[0] AVidPid
# Arg[1] ASerial
TOnUSBPlugEvent = WINFUNCTYPE(None,pchar,pchar)
# Arg[0] APointer
# Arg[1] ASize
TOnIoIPData_API = WINFUNCTYPE(None,ps32,s32)
# Arg[0] AIPAddress
# Arg[1] APort
TOnIoIPConnection = WINFUNCTYPE(None,pchar,s32)
# Arg[0] AIPAddress
# Arg[1] APort
TOnIoIPConnection_API = WINFUNCTYPE(None,pchar,s32)
# Arg[0] AObj
# Arg[1] AName
# Arg[2] AGroup
# Arg[3] ADesc
# Arg[4] AExample
# Arg[5] AParaCount
TLIBWriteAPIDocumentFunc = WINFUNCTYPE(None,ps32,pchar,pchar,pchar,pchar,s32)
# Arg[0] AObj
# Arg[1] AIdx
# Arg[2] AAPIName
# Arg[3] AParaName
# Arg[4] AIsConst
# Arg[5] AParaType
# Arg[6] ADesc
TLIBWriteAPIParaFunc = WINFUNCTYPE(None,ps32,s32,pchar,pchar,cbool,pchar,pchar)
# Arg[0] AObj
# Arg[1] AWriteDoc
# Arg[2] AWritePara
TLIBWriteAPIDocument = WINFUNCTYPE(None,ps32,TLIBWriteAPIDocumentFunc,TLIBWriteAPIParaFunc)
TLIBCheckResult = WINFUNCTYPE(cbool,)
# Arg[0] ACompleteName
TLIBOnSysVarChange = WINFUNCTYPE(None,pchar)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AClientSocket
# Arg[3] AResult
TSSocketListenEvent = WINFUNCTYPE(None,ps32,s32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
TSSocketNotifyEvent = WINFUNCTYPE(None,ps32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AAddr
# Arg[4] APort
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEvent = WINFUNCTYPE(None,ps32,s32,s32,u32,u32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ARemoteEndPoint
# Arg[4] AData
# Arg[5] ASize
TSSocketReceiveEventV2 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ADstEndPoint
# Arg[4] ASrcEndPoint
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEventV3 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AData
# Arg[4] ASize
TSSocketTransmitEvent = WINFUNCTYPE(None,ps32,s32,s32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AClientSocket
# Arg[3] AResult
TSSocketListenEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
TSSocketNotifyEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AAddr
# Arg[4] APort
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,u32,u32,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ARemoteEndPoint
# Arg[4] AData
# Arg[5] ASize
TSSocketReceiveEventV2_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] ADstEndPoint
# Arg[4] ASrcEndPoint
# Arg[5] AData
# Arg[6] ASize
TSSocketReceiveEventV3_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pchar,pchar,pu8,s32)
# Arg[0] AObj
# Arg[1] ASocket
# Arg[2] AResult
# Arg[3] AData
# Arg[4] ASize
TSSocketTransmitEvent_Win32 = WINFUNCTYPE(None,ps32,s32,s32,pu8,s32)
# Arg[0] AIdxChn
# Arg[1] ATimestamp
# Arg[2] APackCmd
# Arg[3] AParameter
# Arg[4] AParameterLength
# Arg[5] AData
# Arg[6] ADataLength
TDatapackageProcessEvent = WINFUNCTYPE(None,u8,s64,u16,pu8,u16,pu8,s32)
# Arg[0] AIdxChn
# Arg[1] ATimestamp
# Arg[2] APackCmd
# Arg[3] AParameter
# Arg[4] AParameterLength
# Arg[5] AData
# Arg[6] ADataLength
TDatapackageProcessEvent_Win32 = WINFUNCTYPE(None,u8,s64,u16,pu8,u16,pu8,s32)
# Arg[0] debugger
# Arg[1] AEvent
# Arg[2] file_name
# Arg[3] line
# Arg[4] user_data
TMPTacDebugCallback = WINFUNCTYPE(s32,pvoid,TMPTacDebugEvent,pchar,s32,ps32)
# Arg[0] AObj
# Arg[1] AProgress100
TReadProgressCallback = WINFUNCTYPE(None,ps32,double)
# Arg[0] AObj
# Arg[1] AProgress
TSeekTimeProgressCallback = CFUNCTYPE(s32,ps32,single)
# Arg[0] AObj
# Arg[1] AComment
# Arg[2] AToTerminate
TReadBLFRealtimeCommentCallback = WINFUNCTYPE(None,ps32,Prealtime_comment_t,pbool)
# Arg[0] AObj
# Arg[1] ASysVar
# Arg[2] AToTerminate
TReadBLFSystemVarCallback = WINFUNCTYPE(None,ps32,PLIBSystemVar,pbool)
# Arg[0] AObj
TReadUnsupportedCallback = WINFUNCTYPE(None,ps32)
# Arg[0] pDiagModuleIndex
# Arg[1] AChnIndex
# Arg[2] ASupportFDCAN
# Arg[3] AMaxDLC
# Arg[4] ARequestID
# Arg[5] ARequestIDIsStd
# Arg[6] AResponseID
# Arg[7] AResponseIDIsStd
# Arg[8] AFunctionID
# Arg[9] AFunctionIDIsStd
Ttsdiag_can_create = WINFUNCTYPE(s32,ps32,u32,u8,u8,u32,cbool,u32,cbool,u32,cbool)
# Arg[0] ADiagModuleIndex
# Arg[1] AFDMode
# Arg[2] ASupportBRS
# Arg[3] AMaxDLC
Ttsdiag_set_fdmode = WINFUNCTYPE(s32,s32,cbool,cbool,s32)
# Arg[0] ADiagModuleIndex
Ttsdiag_can_delete = WINFUNCTYPE(s32,s32)
Ttsdiag_can_delete_all = WINFUNCTYPE(None,)
# Arg[0] ADiagModuleIndex
# Arg[1] AReqDataArray
# Arg[2] AReqDataSize
# Arg[3] AResponseDataArray
# Arg[4] AResponseDataSize
Ttstp_can_request_and_get_response = WINFUNCTYPE(s32,s32,pu8,s32,pu8,ps32)
# Arg[0] ADiagModuleIndex
# Arg[1] AReqDataArray
# Arg[2] AReqDataSize
# Arg[3] AResponseDataArray
# Arg[4] AResponseDataSize
Ttstp_can_request_and_get_response_functional = WINFUNCTYPE(s32,s32,pu8,s32,pu8,ps32)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
N_USData_RevData_Recall_Obj = WINFUNCTYPE(None,s32,s32)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
# Arg[2] ABusType
# Arg[3] ANAD
# Arg[4] AIdentifier
# Arg[5] ATimeStamp
# Arg[6] APayLoad
# Arg[7] ASize
# Arg[8] AError
N_USData_TranslateCompleted_Recall_Obj = WINFUNCTYPE(None,s32,s32,u8,s32,s32,u64,pu8,u32,ISO_TP_RESAULT)
# Arg[0] ATpModuleIndex
# Arg[1] AChn
# Arg[2] ATimeStamp
# Arg[3] APayLoad
# Arg[4] ASize
# Arg[5] AError
N_USData_TranslateCompleted_Recall = WINFUNCTYPE(None,s32,s32,u64,pu8,u32,ISO_TP_RESAULT)
# Arg[0] AMsg
# Arg[1] ALevel
TLogDebuggingInfo_t = WINFUNCTYPE(None,pchar,s32)
# Arg[0] sock
# Arg[1] p
# Arg[2] len
tosun_recv_callback = CFUNCTYPE(None,s32,ps32,u16)
# Arg[0] sock
# Arg[1] p
# Arg[2] src
# Arg[3] dest
# Arg[4] ttl
# Arg[5] tos
tosun_tcp_presend_callback = CFUNCTYPE(None,s32,ps32,Pip_addr_t,Pip_addr_t,u8,u8)
# Arg[0] sock
# Arg[1] p
# Arg[2] len
tosun_tcp_ack_callback = CFUNCTYPE(None,s32,ps32,u16)
